.. tricircle documentation master file, created by
   sphinx-quickstart on Wed Dec 2 17:00:36 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=====================================
Welcome to Tricircle's documentation!
=====================================

User Documentation
==================
.. toctree::
   :maxdepth: 3

   user/index

Contributor Guide
=================
.. toctree::
   :maxdepth: 1

   contributor/index

Admin Guide
===========
.. toctree::
   :maxdepth: 3

   admin/index

Installation Guide
==================
.. toctree::
   :maxdepth: 3

   install/index

Configuration Guide
===================
.. toctree::
   :maxdepth: 3

   configuration/index

